@@ -1,16 +1,16 @@
 # frozen_string_literal: true
 
 module ActionText
-  # Returns the currently loaded version of Action Text as a <tt>Gem::Version</tt>.
+  # Returns the currently loaded version of Action Text as a +Gem::Version+.
   def self.gem_version
     Gem::Version.new VERSION::STRING
   end
 
   module VERSION
     MAJOR = 7
-    MINOR = 0
-    TINY  = 8
-    PRE   = "7"
+    MINOR = 1
+    TINY  = 4
+    PRE   = nil
 
     STRING = [MAJOR, MINOR, TINY, PRE].compact.join(".")
   end
